@@ -6,7 +6,7 @@ def mean(data_list):
     the number of members. It is also known as the average.
     
     Since the value is strongly influenced by outliers, median
-    is a better indicator of central tendency.
+    is generally a better indicator of central tendency.
     
     h3. Example usage
     
@@ -21,23 +21,14 @@ def mean(data_list):
         "mean":http://en.wikipedia.org/wiki/Arithmetic_mean
     
     """
-    # Test to make sure the input is a list or tuple
-    if not isinstance(data_list, (list, tuple)):
-        raise TypeError('First input must be a list or tuple. You passed in a %s' % type(data_list))
-    
     # Convert all the values to floats and test to make sure there aren't any strings in there
     try:
         data_list = map(float, data_list)
     except ValueError:
         raise ValueError('Input values should contain numbers, your first input contains something else')
-    
     # Count the number of values in the sample
     n = len(data_list)
-    
     # Sum up the values in the sample
     sum_ = sum(data_list)
-    
     # Divide them to find the mean
-    mean = sum_ / n
-    
-    return mean
+    return sum_ / n
